==> discover-5.18.3.tar.xz: discover-5.18.3/libdiscover/backends/PackageKitBackend/runservice/main.cpp <==
/***************************************************************************
 *   Copyright © 2016 Aleix Pol Gonzalez <aleixpol@blue-systems.com>       *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or         *
 *   modify it under the terms of the GNU General Public License as        *
 *   published by the Free Software Foundation; either version 2 of        *
 *   the License or (at your option) version 3 or any later version        *
 *   accepted by the membership of KDE e.V. (or its successor approved     *
 *   by the membership of KDE e.V.), which shall act as a proxy            *
 *   defined in Section 14 of version 3 of the license.                    *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program.  If not, see <http://www.gnu.org/licenses/>. *
 ***************************************************************************/

#include <QApplication>
#include <QFile>
#include <QTextStream>
#include <QUrl>
#include <QProcess>
#include <KService>
#include <KRun>

int main(int argc, char** argv)
{
    QApplication app(argc, argv);
    if (app.arguments().size() != 2)
        return 1;

    KService service(app.arguments().constLast());
    if (!service.isValid())
        return 2;

    if (KRun::runApplication(service, {}, nullptr) == 0)
        return 3;

    return 0;
}

==> discover-5.19.4.tar.xz: discover-5.19.4/libdiscover/backends/PackageKitBackend/runservice/main.cpp <==
/***************************************************************************
 *   Copyright © 2016 Aleix Pol Gonzalez <aleixpol@blue-systems.com>       *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or         *
 *   modify it under the terms of the GNU General Public License as        *
 *   published by the Free Software Foundation; either version 2 of        *
 *   the License or (at your option) version 3 or any later version        *
 *   accepted by the membership of KDE e.V. (or its successor approved     *
 *   by the membership of KDE e.V.), which shall act as a proxy            *
 *   defined in Section 14 of version 3 of the license.                    *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program.  If not, see <http://www.gnu.org/licenses/>. *
 ***************************************************************************/

#include <QGuiApplication>
#include <QFile>
#include <QTextStream>
#include <QUrl>
#include <QProcess>
#include <KService>
#include <KIO/ApplicationLauncherJob>

int main(int argc, char** argv)
{
    QGuiApplication app(argc, argv);
    if (app.arguments().size() != 2)
        return 1;

    KService::Ptr service(new KService(app.arguments().constLast()));
    if (!service->isValid())
        return 2;

    KIO::ApplicationLauncherJob *job = new KIO::ApplicationLauncherJob(service);
    job->start();
    QObject::connect(job, &KIO::ApplicationLauncherJob::finished, &app, [&] {
        app.exit(job->error());
    });
    return app.exec();
}
